(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
(*                                                                     *)
(*  Copyright 1996 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the Q Public License version 1.0.               *)
(*                                                                     *)
(***********************************************************************)

(* $Id: toploop.mli,v 1.14 2001/02/12 14:32:37 garrigue Exp $ *)

open Format

(* Interface with toplevel directives *)

type directive_fun =
   | Directive_none of (unit -> unit)
   | Directive_string of (string -> unit)
   | Directive_int of (int -> unit)
   | Directive_ident of (Longident.t -> unit)
   | Directive_bool of (bool -> unit)

val directive_table : (string, directive_fun) Hashtbl.t
        (* Table of known directives, with their execution function *)
val toplevel_env : Env.t ref
        (* Typing environment for the toplevel *)
val print_exception_outcome : formatter -> exn -> unit
        (* Print an exception resulting from the evaluation of user code. *)
val execute_phrase : bool -> formatter -> Parsetree.toplevel_phrase -> bool
        (* Execute the given toplevel phrase. Return [true] if the
           phrase executed with no errors and [false] otherwise.
           First bool says whether the values and types of the results
           should be printed. Uncaught exceptions are always printed. *)
val eval_path: Path.t -> Obj.t
        (* Return the toplevel object referred to by the given path *)

type evaluation_outcome = Result of Obj.t | Exception of exn
val load_lambda : Format.formatter -> Lambda.lambda -> evaluation_outcome

(* Printing of values *)

val print_value: Env.t -> Obj.t -> formatter -> Types.type_expr -> unit
val print_untyped_exception: formatter -> Obj.t -> unit

val install_printer : Path.t -> Types.type_expr -> (Obj.t -> unit) -> unit
val remove_printer : Path.t -> unit

val max_printer_depth: int ref
val max_printer_steps: int ref

(* Hooks for an external parser *)

val print_location : formatter -> Location.t -> unit
val print_warning : Location.t -> formatter -> Warnings.t -> unit
val print_items : Env.t -> Format.formatter -> Types.signature_item list -> unit
val input_name : string ref

(* Used by Trace module *)

val may_trace : bool ref
val use_print_results : bool ref
val refill_lexbuf : string -> int -> int
val first_line : bool ref
val empty_lexbuf : Lexing.lexbuf -> unit
